### Statistical analysis for competition strategies manuscript - 2020 ###
### Written by Borbala Foris in R version 3.5.3 -- "Great Truth" ###

library(psych)

#Get the behavioral measures for each day separately
master <- read.csv("Foris_TableS2.csv",header=T, sep=";") 

#### Get behavioral measures for PRE, POST1, and POST2 periods ####

cow <- unique(master$cows) #cow IDs
  
  pre <- subset(master, days<0 ) #PRE days (days 1-6 before calving)
  
  master.pre <- data.frame()
  for(i in 1:length(cow))
  {
    dat=subset(pre,cows==cow[i])
    print(dim(dat))
    master.pre[i,1:10] <- cbind(dat[1,1:4],
                               mean(dat[,6],na.rm = T),mean(dat[,7],na.rm = T),mean(dat[,8],na.rm = T),
                               mean(dat[,9],na.rm = T),mean(dat[,10],na.rm = T),mean(dat[,11],na.rm = T))
                  
  }
  colnames(master.pre)[5:10] <- colnames(master)[6:11]

  
  post1  <- subset(master, days<4 & days>0) #POST1 days (day 1-3 after calving)
  
  master.post1 <- data.frame()
  for(i in 1:length(cow))
  {
    dat=subset(post1,cows==cow[i])
    print(dim(dat))
    master.post1[i,1:10] <- cbind(dat[1,1:4],
                                mean(dat[,6],na.rm = T),mean(dat[,7],na.rm = T),mean(dat[,8],na.rm = T),
                                mean(dat[,9],na.rm = T),mean(dat[,10],na.rm = T),mean(dat[,11],na.rm = T))
    
  }
  colnames(master.post1)[5:10] <- colnames(master)[6:11]
  
  
  post2  <- subset(master, days>3) #POST2 days (day 4-6 after calving)
  
  master.post2 <- data.frame()
  for(i in 1:length(cow))
  {
    dat=subset(post2,cows==cow[i])
    print(dim(dat))
    master.post2[i,1:10] <- cbind(dat[1,1:4],
                                  mean(dat[,6],na.rm = T),mean(dat[,7],na.rm = T),mean(dat[,8],na.rm = T),
                                  mean(dat[,9],na.rm = T),mean(dat[,10],na.rm = T),mean(dat[,11],na.rm = T))
    
  }
  colnames(master.post2)[5:10] <- colnames(master)[6:11]
  
#### Descriptive statistics for all periods ####
  stat.pre=matrix(0,6,4)
  dat=master.pre[,5:10]
    for(i in 1: ncol(dat))
    {
      stat.pre[i,1]=mean(dat[,i])
      stat.pre[i,2]=sd(dat[,i])
      stat.pre[i,3]=min(dat[,i])
      stat.pre[i,4]=max(dat[,i])
    }
  stat.pre=round(stat.pre,2)
  rownames(stat.pre)=colnames(dat)
  colnames(stat.pre)=c("mean","sd","min","max")
  
  stat.post1=matrix(0,6,4)
  dat=master.post1[,5:10]
    for(i in 1: ncol(dat))
    {
      stat.post1[i,1]=mean(dat[,i])
      stat.post1[i,2]=sd(dat[,i])
      stat.post1[i,3]=min(dat[,i])
      stat.post1[i,4]=max(dat[,i])
    }
  stat.post1=round(stat.post1,2)
  rownames(stat.post1)=colnames(dat)
  colnames(stat.post1)=c("mean","sd","min","max")
  
  stat.post2=matrix(0,6,4)
  dat=master.post2[,5:10]
    for(i in 1: ncol(dat))
    {
      stat.post2[i,1]=mean(dat[,i])
      stat.post2[i,2]=sd(dat[,i])
      stat.post2[i,3]=min(dat[,i])
      stat.post2[i,4]=max(dat[,i])
    }
  stat.post2=round(stat.post2,2)
  rownames(stat.post2)=colnames(dat)
  colnames(stat.post2)=c("mean","sd","min","max")
  
  
  
#### PCA ####
  
  #Prepartum
    for(i in 5:10) #Test if the parameters are normally distributed
      {
        hist(master.pre[,i],main=colnames(master.pre)[i])
        print(colnames(master.pre)[i])
        print(shapiro.test(master.pre[,i]))
      }
  
  dat=master.pre[,5:10] #prepartum behavioral measures
  mat=cor(master.pre[,5:10],method="spearman") #Use Spearman correlation matrix as input for the PCA
  
  #Test PCA applicability and the number of components to extract
  KMO(mat) #MSA=0.55
  fa.parallel(mat,n.obs=52,fa="pc",n.iter=1000) #Horn parallel test, 2 components should be extracted
  
  aa=pca(mat,nfactors=2, scores=T,n.obs=52,rotate = "varimax")
  print(aa) #PCA results, loadings matrix, variance explained
  aa$values #eigenvalues
  aa$weights #this is used to calculate scores
  
  #Postpartum behavioral measures
  dat1=master.post1[,5:10]
  dat2=master.post2[,5:10]
  
  #Scores have to be generated using the scaled data and weights
  scores=scale(dat)%*%aa$weights
  scores1=scale(dat1)%*%aa$weights
  scores2=scale(dat2)%*%aa$weights
  
  #save the RC scores in a separate table
  pc_data=cbind(master.pre[,1:4],scores,scores1,scores2) 
  colnames(pc_data)[5:10]=paste(c("pre","pre","post1","post1","post2","post2"),colnames(pc_data)[5:10],sep="_")
  
#### RC score stability between periods ####
  
  cor(pc_data[,c(5,7,9)])
  cor.test(pc_data$pre_RC1,pc_data$post1_RC1)
  cor.test(pc_data$post1_RC1,pc_data$post2_RC1)
  cor.test(pc_data$pre_RC1,pc_data$post2_RC1)
  p.adjust(c(0.009537,0.04966,0.001658),method="BH")
  
  cor(pc_data[,c(6,8,10)])
  cor.test(pc_data$pre_RC2,pc_data$post1_RC2)
  cor.test(pc_data$post1_RC2,pc_data$post2_RC2)
  cor.test(pc_data$pre_RC2,pc_data$post2_RC2)
  p.adjust(c(3.543e-07,4.185e-09,7.192e-07),method="BH")
  
#### Effect of sickness and parity on RC scores in each period separately ####
  
  #Prepartum
  m1=lm(pre_RC1 ~ as.factor(sick)+ as.factor(parity2),data = pc_data ) #no effect
  m2=lm(pre_RC1 ~ as.factor(sick)*as.factor(parity2),data = pc_data )
  anova(m1,m2) #simple model is ok
  summary(m1)
  #plot(m1)
  anova(m1)
  
  m1=lm(pre_RC2 ~ as.factor(sick)+ as.factor(parity2),data = pc_data ) #parity tendency
  m2=lm(pre_RC2 ~ as.factor(sick)*as.factor(parity2),data = pc_data )
  anova(m1,m2) #simple model is ok
  summary(m1)
  #plot(m1)
  anova(m1)
  
  #Postpartum 1
  m1=lm(post1_RC1 ~ as.factor(sick)+ as.factor(parity2),data = pc_data ) #no effect
  m2=lm(post1_RC1 ~ as.factor(sick)*as.factor(parity2),data = pc_data )
  anova(m1,m2) #simple model is ok
  summary(m1)
  #plot(m1)
  anova(m1)
  
  m1=lm(post1_RC2 ~ as.factor(sick)+ as.factor(parity2),data = pc_data ) #no effect
  m2=lm(post1_RC2 ~ as.factor(sick)*as.factor(parity2),data = pc_data )
  anova(m1,m2) #simple model is ok
  summary(m1)
  #plot(m1)
  anova(m1)
  
  #Postpartum 2
  m1=lm(post2_RC1 ~ as.factor(sick)+ as.factor(parity2),data = pc_data ) #no effect
  m2=lm(post2_RC1 ~ as.factor(sick)*as.factor(parity2),data = pc_data )
  anova(m1,m2) #simple model is ok
  summary(m1)
  #plot(m1)
  anova(m1)
  
  m1=lm(post2_RC2 ~ as.factor(sick)+ as.factor(parity2),data = pc_data ) #no effect
  m2=lm(post2_RC2 ~ as.factor(sick)*as.factor(parity2),data = pc_data )
  anova(m1,m2) #simple model is ok
  summary(m1)
  #plot(m1)
  anova(m1)
  
#### Calculate 2 dimensional Eucledian distances for each cow between PRE-POST1 and POST1-POST2 ####
  
  dd=matrix(0,dim(pc_data)[1],3)
  pc_data2=pc_data
  colnames(pc_data2)[5:10]=c(rep(c("RC1","RC2"),3))#adjust colnames to be able to rbind
  
  for(i in 1:dim(pc_data2)[1]) #get the distances
  {
    dd[i,1]=pc_data2[i,1]
    dd[i,2]=dist(rbind(pc_data2[i,5:6],pc_data2[i,7:8]))
    dd[i,3]=dist(rbind(pc_data2[i,7:8],pc_data2[i,9:10]))
  }
  
  pc_dist=cbind(pc_data,dd[,2:3])
  colnames(pc_dist)[11:12]=c("dist_pre_post1", "dist_post1_post2")
  
#### Effect of sickness and parity on strategy change PRE-POST1 and POST1-POST2 ####

  m1=lm(pc_dist$dist_pre_post1 ~ as.factor(pc_dist$sick)+as.factor(pc_dist$parity2)) #tendency of sickness effect
  m2=lm(pc_dist$dist_pre_post1 ~ as.factor(pc_dist$sick)*as.factor(pc_dist$parity2))
  anova(m1,m2)#simple model is ok
  summary(m1)
  anova(m1)
  #plot(m1)
  
  m1=lm(pc_dist$dist_post1_post2 ~ as.factor(pc_dist$sick) +as.factor(pc_dist$parity2)) #sickness effect
  m2=lm(pc_dist$dist_post1_post2 ~ as.factor(pc_dist$sick)*as.factor(pc_dist$parity2))
  anova(m1,m2) #simple model is ok
  summary(m1)
  anova(m1)
  #plot(m1)
  
#### PLOTS ####

  #### Figure 1 - PCA results ####

  pdf(file="Figure_1.pdf",height=11,width=4)
  par(mfrow=c(3,1),mar=c(4,4,1.5,1.5))
  
  plot(pc_data$pre_RC1,pc_data$pre_RC2,xlim=c(-3,3),ylim=c(-3,3),
       xlab="RC1 - Asynchrony",ylab="RC2 - Competitiveness",cex.lab=1.2,
       col=c("snow4","tomato")[as.factor(pc_data$sick)],
       pch=c(17,19)[as.factor(pc_data$parity2)])
  abline(h=0,col="seashell4")
  abline(v=0,col="seashell4")
  mtext("(A)",side=3,at=-3.5,cex=0.8,font=2)
  legend(1.5,3,legend=c("healthy","metritic"),fill=c("snow4","tomato"),cex=0.96,bty="n")
  legend(1.5,2.4,legend=c("primiparous","multiparous"),pch=c(17,19),cex=0.96,bty="n")
  
  plot(pc_data$post1_RC1,pc_data$post1_RC2,xlim=c(-3,3),ylim=c(-3,3),
       xlab="RC1 - Asynchrony",ylab="RC2 - Competitiveness",cex.lab=1.2,
       col=c("snow4","tomato")[as.factor(pc_data$sick)],
       pch=c(17,19)[as.factor(pc_data$parity2)])
  abline(h=0,col="seashell4")
  abline(v=0,col="seashell4")
  mtext("(B)",side=3,at=-3.5,cex=0.8,font=2)
  legend(1.5,3,legend=c("healthy","metritic"),fill=c("snow4","tomato"),cex=0.96,bty="n")
  legend(1.5,2.4,legend=c("primiparous","multiparous"),pch=c(17,19),cex=0.96,bty="n")
  
  plot(pc_data$post2_RC1,pc_data$post2_RC2,xlim=c(-3,3),ylim=c(-3,3),
       xlab="RC1 - Asynchrony",ylab="RC2 - Competitiveness",cex.lab=1.2,
       col=c("snow4","tomato")[as.factor(pc_data$sick)],
       pch=c(17,19)[as.factor(pc_data$parity2)])
  abline(h=0,col="seashell4")
  abline(v=0,col="seashell4")
  mtext("(C)",side=3,at=-3.5,cex=0.8,font=2)
  legend(1.5,3,legend=c("healthy","metritic"),fill=c("snow4","tomato"),cex=0.96,bty="n")
  legend(1.5,2.4,legend=c("primiparous","multiparous"),pch=c(17,19),cex=0.96,bty="n")
  
  dev.off()
  
  
  #### Figure 2 - Strategy change boxplots ####
  library(ggplot2)
  
    #Put the data in long format
    pc_dist1=pc_dist[,c(1:4,11:12)]
    pc_dist2=cbind(rep(pc_dist1$cow,2),rep(pc_dist1$sick,2),rep(pc_dist1$parity2,2),c(rep(1,52),rep(2,52)),
                      c(pc_dist1$dist_pre_post1,pc_dist1$dist_post1_post2))
    colnames(pc_dist2)=c("cow","sick","parity","period","change")
    pc_dist2=as.data.frame(pc_dist2)
  
  pdf("Figure_2.pdf",height = 5, width=7)
  ggplot(pc_dist2, aes( x=as.factor(period),y=change,color=as.factor(sick))) +
    ylim(0,3)+
    geom_boxplot(position = position_dodge(), outlier.shape = NA) +
    scale_color_manual(values = c("snow4","tomato"),labels = c("healthy", "metritic"))+
    geom_jitter( alpha = 0.35,width=0.2,height = 0.1) +
    theme_classic(base_size = 15) +
    scale_x_discrete(labels=c("1" = "PRE - POST1", "2" = "POST1 - POST2"))+
    labs(title = "", x="", y = "Strategy change",color="")
  
  dev.off()
  
  #### Figure S1 - Strategy change arrows ####
  library(shape)#this is to draw nice arrows
  
  pdf("Figure S1.pdf",height = 8,width=15)
  par(mfrow=c(1,2))
  
  plot(pc_data$pre_RC1,pc_data$pre_RC2,pch=15,xlim=c(-3,3),ylim=c(-3,3),
       xlab="RC1 - Asynchrony",ylab="RC2 - Competitiveness",cex.lab=1.5,col=c("snow4","tomato")[as.factor(pc_data$sick)],
       main = "PRE - POST1")
  Arrows(pc_data$pre_RC1,pc_data$pre_RC2,pc_data$post1_RC1,pc_data$post1_RC2,
         col = c("snow4","tomato")[as.factor(pc_data$sick)],lwd = 2,arr.lwd=0.5,arr.adj = 0.3)
  abline(h=0,v=0,col="seashell4")
  legend(1, 3,legend=c("healthy","metritic"), col=c("snow4","tomato"), pch="I",cex=1.2)
  
  plot(pc_data$post1_RC1,pc_data$post1_RC2,pch=15,xlim=c(-3,3),ylim=c(-3,3),
       xlab="RC1 - Asynchrony",ylab="RC2 - Competitiveness",cex.lab=1.5, col=c("snow4","tomato")[as.factor(pc_data$sick)],
       main = "POST1 - POST2")
  Arrows(pc_data$post1_RC1,pc_data$post1_RC2,pc_data$post2_RC1,pc_data$post2_RC2,
         col = c("snow4","tomato")[as.factor(pc_data$sick)],lwd = 2,arr.lwd=0.5,arr.adj = 0.3)
  abline(h=0,v=0,col="seashell4")
  legend(1, 3,legend=c("healthy","metritic"), col=c("snow4","tomato"), pch="I",cex=1.2)
  
  dev.off()